@@ -1,13 +1,33 @@
 from copy import copy
 import sqlalchemy as sa
 from sqlalchemy_utils.functions import primary_keys
-from .builder import VersionedBuilder
 from .expression_reflector import ClassExpressionReflector
+from .utils import declarative_base
 from .version import VersionClassBase
 
 
-class VersionedModelBuilder(VersionedBuilder):
+class ModelBuilder(object):
+    """
+    VersionedModelBuilder handles the building of History models based on
+    parent table attributes and versioning configuration.
+    """
+    def __init__(self, versioning_manager, model):
+        """
+        :param versioning_manager:
+            VersioningManager object
+        :param model:
+            SQLAlchemy declarative model object that acts as a parent for the
+            built history model
+        """
+        self.manager = versioning_manager
+        self.model = model
+
     def build_parent_relationship(self):
+        """
+        Builds a relationship between currently built history class and
+        parent class (the model whose history the currently build history
+        class represents).
+        """
         conditions = []
         foreign_keys = []
         for primary_key in primary_keys(self.model):
@@ -35,9 +55,14 @@ class VersionedModelBuilder(VersionedBuilder):
             )
 
     def build_transaction_relationship(self, tx_log_class):
+        """
+        Builds a relationship between currently built history class and
+        TransactionLog class.
+
+        :param tx_log_class: TransactionLog class
+        """
         # Only define transaction relation if it doesn't already exist in
         # parent class.
-        naming_func = self.manager.options['relation_naming_function']
         if not hasattr(self.extension_class, 'transaction'):
             self.extension_class.transaction = sa.orm.relationship(
                 tx_log_class,
@@ -46,13 +71,20 @@ class VersionedModelBuilder(VersionedBuilder):
                     self.extension_class.transaction_id
                 ),
                 foreign_keys=[self.extension_class.transaction_id],
-                backref=naming_func(self.model.__name__)
+                backref=self.manager.options['relation_naming_function'](
+                    self.model.__name__
+                )
             )
 
     def build_changes_relationship(self, tx_changes_class):
+        """
+        Builds a relationship between currently built history class and
+        TransactionChanges class.
+
+        :param tx_changes_class: TransactionChanges class
+        """
         # Only define changes relation if it doesn't already exist in
         # parent class.
-        naming_func = self.manager.options['relation_naming_function']
         if not hasattr(self.extension_class, 'changes'):
             self.extension_class.changes = sa.orm.relationship(
                 tx_changes_class,
@@ -61,23 +93,34 @@ class VersionedModelBuilder(VersionedBuilder):
                     self.extension_class.transaction_id
                 ),
                 foreign_keys=[tx_changes_class.transaction_id],
-                backref=naming_func(self.model.__name__)
+                backref=self.manager.options['relation_naming_function'](
+                    self.model.__name__
+                )
             )
 
     def find_closest_versioned_parent(self):
+        """
+        Finds the closest versioned parent for current parent model.
+        """
         for class_ in self.model.__bases__:
             if class_ in self.manager.history_class_map:
                 return (self.manager.history_class_map[class_], )
 
     def base_classes(self):
+        """
+        Returns all base classes for history model.
+        """
         parents = (
             self.find_closest_versioned_parent()
-            or self.option('base_classes')
-            or (self.manager.declarative_base(self.model), )
+            or self.manager.option(self.model, 'base_classes')
+            or (declarative_base(self.model), )
         )
         return parents + (VersionClassBase, )
 
     def inheritance_args(self):
+        """
+        Return mapper inheritance args for currently built history model.
+        """
         if self.find_closest_versioned_parent():
             reflector = ClassExpressionReflector(self.model)
             inherit_condition = reflector(
@@ -89,6 +132,9 @@ class VersionedModelBuilder(VersionedBuilder):
         return {}
 
     def build_model(self, table):
+        """
+        Build history model class.
+        """
         mapper_args = {}
         mapper_args.update(self.inheritance_args())
 
@@ -102,6 +148,10 @@ class VersionedModelBuilder(VersionedBuilder):
         )
 
     def __call__(self, table, tx_log_class, tx_changes_class):
+        """
+        Build history model and relationships to parent model, transaction
+        log model and transaction changes model.
+        """
         # versioned attributes need to be copied for each child class,
         # otherwise each child class would share the same __versioned__
         # option dict
