@@ -1,41 +1,8 @@
 from collections import OrderedDict
 from functools import wraps
-import itertools
 import sqlalchemy as sa
 from .operation import Operation
-
-
-def versioned_objects(session):
-    iterator = itertools.chain(session.new, session.dirty, session.deleted)
-
-    return [
-        obj for obj in iterator
-        if is_versioned(obj)
-    ]
-
-
-def is_versioned(obj):
-    return (
-        hasattr(obj, '__versioned__') and
-        (
-            (
-                'versioning' in obj.__versioned__ and
-                obj.__versioned__['versioning']
-            ) or
-            'versioning' not in obj.__versioned__
-        )
-    )
-
-
-def identity(obj):
-    id_ = []
-    for attr in obj._sa_class_manager.values():
-        prop = attr.property
-        if isinstance(prop, sa.orm.ColumnProperty):
-            column = prop.columns[0]
-            if column.primary_key:
-                id_.append(getattr(obj, column.name))
-    return tuple(id_)
+from .utils import is_versioned, identity
 
 
 def tracked_operation(func):
@@ -59,6 +26,10 @@ class UnitOfWork(object):
         self.reset()
 
     def reset(self):
+        """
+        Reset the internal state of this UnitOfWork object. Normally this is
+        called after transaction has been committed or rolled back.
+        """
         self.current_transaction_id = None
         self.operations = OrderedDict()
         self._committing = False
@@ -66,6 +37,12 @@ class UnitOfWork(object):
         self.pending_statements = []
 
     def track_operations(self, mapper):
+        """
+        Attach listeners for specified mapper that track SQL inserts, updates
+        and deletes.
+
+        :param mapper: mapper to track the SQL operations from
+        """
         sa.event.listen(
             mapper, 'after_delete', self.track_deletes
         )
@@ -77,6 +54,13 @@ class UnitOfWork(object):
         )
 
     def track_session(self, session):
+        """
+        Attach listeners that track the operations (flushing, committing and
+        rolling back) of given session. This method should be used in
+        conjuction with `track_operations`.
+
+        :param session: SQLAlchemy session to track the operations from
+        """
         sa.event.listen(
             session, 'after_flush', self.after_flush
         )
@@ -84,10 +68,10 @@ class UnitOfWork(object):
             session, 'before_commit', self.before_commit
         )
         sa.event.listen(
-            session, 'after_commit', self.clear_transaction
+            session, 'after_commit', self.clear
         )
         sa.event.listen(
-            session, 'after_rollback', self.clear_transaction
+            session, 'after_rollback', self.clear
         )
 
     @tracked_operation
@@ -103,6 +87,10 @@ class UnitOfWork(object):
 
     @tracked_operation
     def track_updates(self, key, target):
+        """
+        Tracks object update operations. Whenever object is deleted it is
+        added to this UnitOfWork's internal operations dictionary.
+        """
         self.operations[key] = {
             'target': target,
             'operation_type': Operation.UPDATE
@@ -110,30 +98,39 @@ class UnitOfWork(object):
 
     @tracked_operation
     def track_deletes(self, key, target):
+        """
+        Tracks object deletion operations. Whenever object is deleted it is
+        added to this UnitOfWork's internal operations dictionary.
+        """
         self.operations[key] = {
             'target': target,
             'operation_type': Operation.DELETE
         }
 
-    def create_version_objects(self, session):
+    def create_history_objects(self, session):
+        """
+        Create history objects for given session based on operations collected
+        by insert, update and deleted trackers.
+
+        :param session: SQLAlchemy session object
+        """
         if not self.manager.options['versioning']:
             return
 
-        if self._committing:
-            for key, value in self.operations.items():
-                if not session.is_modified(
-                    value['target'], include_collections=False
-                ) and value['target'] not in session.deleted:
-                    continue
-                version_obj = value['target'].__versioned__['class']()
-                session.add(version_obj)
+        for key, value in self.operations.items():
+            if not session.is_modified(
+                value['target'], include_collections=False
+            ) and value['target'] not in session.deleted:
+                continue
+            version_obj = value['target'].__versioned__['class']()
+            session.add(version_obj)
 
-                version_obj.operation_type = value['operation_type']
-                self.assign_attributes(value['target'], version_obj)
+            version_obj.operation_type = value['operation_type']
+            self.assign_attributes(value['target'], version_obj)
 
-                version_obj.transaction_id = (
-                    self.current_transaction_id
-                )
+            version_obj.transaction_id = (
+                self.current_transaction_id
+            )
 
     def create_association_versions(self, session):
         for stmt in self.pending_statements:
@@ -141,12 +138,20 @@ class UnitOfWork(object):
             session.execute(stmt)
 
     def after_flush(self, session, flush_context):
+        """
+        SQLAlchemy after_flush event listener that handles all the logic for
+        creating necessary TransactionLog, TransactionChanges and History
+        objects.
+
+        :param session: SQLAlchemy session object
+        :param flush_context: flush_context dictionary
+        """
         if not self.manager.options['versioning']:
             return
 
         if self._committing:
             self.create_transaction_log_entry(session)
-            self.create_version_objects(session)
+            self.create_history_objects(session)
             self.create_association_versions(session)
             self.create_transaction_changes_entries(session)
 
@@ -154,6 +159,12 @@ class UnitOfWork(object):
             self._committing = False
 
     def create_transaction_log_entry(self, session):
+        """
+        Creates TransactionLog object for current transaction. We use raw
+        insert here to be able to get current transaction id right away.
+
+        :param session: SQLAlchemy session
+        """
         if self.current_transaction_id:
             return self.current_transaction_id
 
@@ -184,6 +195,11 @@ class UnitOfWork(object):
             return self.current_transaction_id
 
     def changed_entities(self, session):
+        """
+        Return a set of changed versioned entities for given session.
+
+        :param session: SQLAlchemy session object
+        """
         changed_entities = set()
 
         for key, value in self.operations.items():
@@ -195,6 +211,14 @@ class UnitOfWork(object):
         return changed_entities
 
     def create_transaction_changes_entries(self, session):
+        """
+        Create transaction changes entries based on all operations that
+        occurred during this UnitOfWork. For each entity that has been affected
+        by an operation during this UnitOfWork this method creates a new
+        TransactionChanges object.
+
+        :param session: SQLAlchemy session object
+        """
         for entity in self.changed_entities(session):
             changes = self.manager.transaction_changes_cls(
                 transaction_id=self.current_transaction_id,
@@ -203,15 +227,31 @@ class UnitOfWork(object):
             session.add(changes)
 
     def before_commit(self, session):
+        """
+        SQLAlchemy before commit listener that marks the internal state of this
+        UnitOfWork as committing. This state is later on used by after_flush
+        listener which checks if the session is actually committing or if the
+        flush occurs before session commit.
+
+        :param session: SQLAlchemy session object
+        """
         self._committing = True
 
-    def clear_transaction(self, session):
-        self.current_transaction_id = None
-        self.operations = OrderedDict()
-        self._committing = False
-        self.pending_statements = []
+    def clear(self, session):
+        """
+        Simple SQLAlchemy listener that is being invoked after succesful
+        transaction commit or when transaction rollback occurs. The purpose of
+        this listener is to reset this UnitOfWork back to its initialization
+        state.
 
-    def version_association_table_record(self, conn, table_name, params, op):
+        :param session: SQLAlchey session object
+        """
+        self.reset()
+
+    def append_association_operation(self, conn, table_name, params, op):
+        """
+        Appends history association operation to pending_statements list.
+        """
         params['operation_type'] = op
         stmt = (
             self.manager.metadata.tables[table_name + '_history']
@@ -220,9 +260,13 @@ class UnitOfWork(object):
         )
         self.pending_statements.append(stmt)
 
-    def version_association_table_records(
+    def track_association_operations(
         self, conn, cursor, statement, parameters, context, executemany
     ):
+        """
+        Tracks association operations and adds the generated history
+        association operations to pending_statements list.
+        """
         if not self.manager.options['versioning']:
             return
 
@@ -244,15 +288,25 @@ class UnitOfWork(object):
                     # multi-inserts, hence we need to convert the orignal
                     # multi-insert into batch of normal inserts
                     for params in parameters:
-                        self.version_association_table_record(
+                        self.append_association_operation(
                             conn, table_name, params, op
                         )
                 else:
-                    self.version_association_table_record(
+                    self.append_association_operation(
                         conn, table_name, parameters, op
                     )
 
     def assign_attributes(self, parent_obj, version_obj):
+        """
+        Assigns attributes values from parent object to version object. If the
+        parent object is deleted this method assigns None values to all version
+        object's attributes.
+
+        :param parent_obj:
+            Parent object to get the attribute values from
+        :param version_obj:
+            Version object to assign the attribute values to
+        """
         excluded_attributes = self.manager.option(parent_obj, 'exclude')
         for key, attr in parent_obj._sa_class_manager.items():
             if key in excluded_attributes:
