@@ -2,9 +2,7 @@ import sqlalchemy as sa
 from sqlalchemy import create_engine
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.orm import sessionmaker
-from sqlalchemy_continuum import (
-    make_versioned, versioning_manager, Versioned
-)
+from sqlalchemy_continuum import make_versioned, versioning_manager
 from sqlalchemy_continuum.ext.flask import (
     versioning_manager as flask_versioning_manager
 )
@@ -74,7 +72,7 @@ class TestCase(object):
         self.connection.close()
 
     def create_models(self):
-        class Article(self.Model, Versioned):
+        class Article(self.Model):
             __tablename__ = 'article'
             __versioned__ = {
                 'base_classes': (self.Model, )
@@ -85,7 +83,7 @@ class TestCase(object):
             content = sa.Column(sa.UnicodeText)
             description = sa.Column(sa.UnicodeText)
 
-        class Tag(self.Model, Versioned):
+        class Tag(self.Model):
             __tablename__ = 'tag'
             __versioned__ = {
                 'base_classes': (self.Model, )
